@@ -1,24 +1,26 @@
-# Copyright (c) 2013, Sascha Peilicke <saschpe@gmx.de>
+# Copyright 2013 Sascha Peilicke
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU General Public License
-# along with this program (see the file COPYING); if not, write to the
-# Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+from __future__ import print_function
 
 import os
-import site
 import sys
 import traceback
-import urlparse
+try:
+    import urllib.parse as urlparse
+except ImportError:
+    import urlparse
 
 import rapport.config
 import rapport.util
@@ -80,7 +82,7 @@ def _get_plugin_dirs():
     plugin_dirs = [
         os.path.expanduser(os.path.join("~", ".rapport", "plugins")),
         os.path.join("rapport", "plugins")  # Local dev tree
-    ] + map(lambda d: os.path.join(d, "rapport", "plugins"), site.getsitepackages())
+    ]
     return plugin_dirs
 
 
@@ -111,11 +113,11 @@ def discover():
                     plugin_files.append(os.path.join(plugin_dir, plugin_file))
 
     if rapport.config.get_int("rapport", "verbosity") >= 2:
-        print "Found plugin modules: {0}".format(plugin_files)
+        print("Found plugin modules: {0}".format(plugin_files))
 
     for plugin_file in plugin_files:
         if rapport.config.get_int("rapport", "verbosity") >= 2:
-            print "Importing module {0}".format(_path_to_module(plugin_file))
+            print("Importing module {0}".format(_path_to_module(plugin_file)))
         __import__(_path_to_module(plugin_file))
 
 
@@ -126,7 +128,7 @@ def register(name, klass):
     """Add a plugin to the plugin catalog.
     """
     if rapport.config.get_int("rapport", "verbosity") >= 1:
-        print "Registered plugin: {0}".format(name)
+        print("Registered plugin: {0}".format(name))
     _PLUGIN_CATALOG[name] = klass
 
 
@@ -135,20 +137,20 @@ def init(name, *args, **kwargs):
     """
     if name in _PLUGIN_CATALOG:
         if rapport.config.get_int("rapport", "verbosity") >= 2:
-            print "Initialize plugin {0}: {1} {2}".format(name, args, kwargs)
+            print("Initialize plugin {0}: {1} {2}".format(name, args, kwargs))
         try:
             return _PLUGIN_CATALOG[name](*args, **kwargs)
         except (ValueError, TypeError) as e:
-            print >>sys.stderr, "Failed to initialize plugin {0}: {1}!".format(name, e)
+            print("Failed to initialize plugin {0}: {1}!".format(name, e), file=sys.stderr)
     else:
-        print >>sys.stderr, "Failed to initialize plugin {0}: Not in catalog!".format(name)
+        print("Failed to initialize plugin {0}: Not in catalog!".format(name), file=sys.stderr)
 
 
 def init_from_config():
     plugins = []
     for plugin in rapport.config.plugins():
         plugins.append(init(**plugin))
-    return filter(bool, plugins)
+    return list(filter(bool, plugins))
 
 
 def catalog():
